@@ -19,6 +19,7 @@ export PROG=`basename $0`
 DIR=`dirname $0`
 USER=`/usr/bin/whoami`
 HOST=`hostname`
+export EXECUTED_SCRIPT=${PROG}
 
 ########################################
 # Function
@@ -39,7 +40,9 @@ function SIGINTExit()
 trap SIGINTExit 2
 
 date +"### Hinemos Agent installer started at %Y-%m-%d %H:%M:%S ###" >> ${INSTALL_LOG}
-${SCRIPT_DIR}/agent_installer_all jp 2>&1 | tee -a ${INSTALL_LOG}
+${SCRIPT_DIR}/agent_installer_all -l jp $@ 2>&1 | tee -a ${INSTALL_LOG}
+RETURN=${PIPESTATUS[0]}
+
 date +"### Hinemos Agent installer ended at %Y-%m-%d %H:%M:%S ###" >> ${INSTALL_LOG}
 
-exit $?
+exit ${RETURN}
