@@ -5,14 +5,13 @@ import java.util.ArrayList;
 import java.util.List;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlType;
 
 
 /**
- * <p>Java class for commandResultDTO complex type.
+ * <p>commandResultDTO complex typeのJavaクラス。
  * 
- * <p>The following schema fragment specifies the expected content contained within this class.
+ * <p>次のスキーマ・フラグメントは、このクラス内に含まれる予期されるコンテンツを指定します。
  * 
  * <pre>
  * &lt;complexType name="commandResultDTO">
@@ -25,7 +24,7 @@ import javax.xml.bind.annotation.XmlType;
  *         &lt;element name="exitCode" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
  *         &lt;element name="exitDate" type="{http://www.w3.org/2001/XMLSchema}long" minOccurs="0"/>
  *         &lt;element name="facilityId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
- *         &lt;element name="invalidLines">
+ *         &lt;element name="invalidLines" minOccurs="0">
  *           &lt;complexType>
  *             &lt;complexContent>
  *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
@@ -48,7 +47,7 @@ import javax.xml.bind.annotation.XmlType;
  *           &lt;/complexType>
  *         &lt;/element>
  *         &lt;element name="monitorId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
- *         &lt;element name="results">
+ *         &lt;element name="results" minOccurs="0">
  *           &lt;complexType>
  *             &lt;complexContent>
  *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
@@ -106,10 +105,8 @@ public class CommandResultDTO {
     protected Integer exitCode;
     protected Long exitDate;
     protected String facilityId;
-    @XmlElement(required = true)
     protected CommandResultDTO.InvalidLines invalidLines;
     protected String monitorId;
-    @XmlElement(required = true)
     protected CommandResultDTO.Results results;
     protected String stderr;
     protected String stdout;
@@ -117,7 +114,7 @@ public class CommandResultDTO {
     protected String user;
 
     /**
-     * Gets the value of the collectDate property.
+     * collectDateプロパティの値を取得します。
      * 
      * @return
      *     possible object is
@@ -129,7 +126,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Sets the value of the collectDate property.
+     * collectDateプロパティの値を設定します。
      * 
      * @param value
      *     allowed object is
@@ -141,7 +138,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Gets the value of the command property.
+     * commandプロパティの値を取得します。
      * 
      * @return
      *     possible object is
@@ -153,7 +150,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Sets the value of the command property.
+     * commandプロパティの値を設定します。
      * 
      * @param value
      *     allowed object is
@@ -165,7 +162,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Gets the value of the executeDate property.
+     * executeDateプロパティの値を取得します。
      * 
      * @return
      *     possible object is
@@ -177,7 +174,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Sets the value of the executeDate property.
+     * executeDateプロパティの値を設定します。
      * 
      * @param value
      *     allowed object is
@@ -189,7 +186,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Gets the value of the exitCode property.
+     * exitCodeプロパティの値を取得します。
      * 
      * @return
      *     possible object is
@@ -201,7 +198,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Sets the value of the exitCode property.
+     * exitCodeプロパティの値を設定します。
      * 
      * @param value
      *     allowed object is
@@ -213,7 +210,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Gets the value of the exitDate property.
+     * exitDateプロパティの値を取得します。
      * 
      * @return
      *     possible object is
@@ -225,7 +222,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Sets the value of the exitDate property.
+     * exitDateプロパティの値を設定します。
      * 
      * @param value
      *     allowed object is
@@ -237,7 +234,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Gets the value of the facilityId property.
+     * facilityIdプロパティの値を取得します。
      * 
      * @return
      *     possible object is
@@ -249,7 +246,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Sets the value of the facilityId property.
+     * facilityIdプロパティの値を設定します。
      * 
      * @param value
      *     allowed object is
@@ -261,7 +258,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Gets the value of the invalidLines property.
+     * invalidLinesプロパティの値を取得します。
      * 
      * @return
      *     possible object is
@@ -273,7 +270,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Sets the value of the invalidLines property.
+     * invalidLinesプロパティの値を設定します。
      * 
      * @param value
      *     allowed object is
@@ -285,7 +282,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Gets the value of the monitorId property.
+     * monitorIdプロパティの値を取得します。
      * 
      * @return
      *     possible object is
@@ -297,7 +294,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Sets the value of the monitorId property.
+     * monitorIdプロパティの値を設定します。
      * 
      * @param value
      *     allowed object is
@@ -309,7 +306,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Gets the value of the results property.
+     * resultsプロパティの値を取得します。
      * 
      * @return
      *     possible object is
@@ -321,7 +318,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Sets the value of the results property.
+     * resultsプロパティの値を設定します。
      * 
      * @param value
      *     allowed object is
@@ -333,7 +330,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Gets the value of the stderr property.
+     * stderrプロパティの値を取得します。
      * 
      * @return
      *     possible object is
@@ -345,7 +342,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Sets the value of the stderr property.
+     * stderrプロパティの値を設定します。
      * 
      * @param value
      *     allowed object is
@@ -357,7 +354,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Gets the value of the stdout property.
+     * stdoutプロパティの値を取得します。
      * 
      * @return
      *     possible object is
@@ -369,7 +366,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Sets the value of the stdout property.
+     * stdoutプロパティの値を設定します。
      * 
      * @param value
      *     allowed object is
@@ -381,7 +378,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Gets the value of the timeout property.
+     * timeoutプロパティの値を取得します。
      * 
      */
     public boolean isTimeout() {
@@ -389,7 +386,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Sets the value of the timeout property.
+     * timeoutプロパティの値を設定します。
      * 
      */
     public void setTimeout(boolean value) {
@@ -397,7 +394,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Gets the value of the user property.
+     * userプロパティの値を取得します。
      * 
      * @return
      *     possible object is
@@ -409,7 +406,7 @@ public class CommandResultDTO {
     }
 
     /**
-     * Sets the value of the user property.
+     * userプロパティの値を設定します。
      * 
      * @param value
      *     allowed object is
@@ -422,9 +419,9 @@ public class CommandResultDTO {
 
 
     /**
-     * <p>Java class for anonymous complex type.
+     * <p>anonymous complex typeのJavaクラス。
      * 
-     * <p>The following schema fragment specifies the expected content contained within this class.
+     * <p>次のスキーマ・フラグメントは、このクラス内に含まれる予期されるコンテンツを指定します。
      * 
      * <pre>
      * &lt;complexType>
@@ -490,9 +487,9 @@ public class CommandResultDTO {
 
 
         /**
-         * <p>Java class for anonymous complex type.
+         * <p>anonymous complex typeのJavaクラス。
          * 
-         * <p>The following schema fragment specifies the expected content contained within this class.
+         * <p>次のスキーマ・フラグメントは、このクラス内に含まれる予期されるコンテンツを指定します。
          * 
          * <pre>
          * &lt;complexType>
@@ -520,7 +517,7 @@ public class CommandResultDTO {
             protected String value;
 
             /**
-             * Gets the value of the key property.
+             * keyプロパティの値を取得します。
              * 
              * @return
              *     possible object is
@@ -532,7 +529,7 @@ public class CommandResultDTO {
             }
 
             /**
-             * Sets the value of the key property.
+             * keyプロパティの値を設定します。
              * 
              * @param value
              *     allowed object is
@@ -544,7 +541,7 @@ public class CommandResultDTO {
             }
 
             /**
-             * Gets the value of the value property.
+             * valueプロパティの値を取得します。
              * 
              * @return
              *     possible object is
@@ -556,7 +553,7 @@ public class CommandResultDTO {
             }
 
             /**
-             * Sets the value of the value property.
+             * valueプロパティの値を設定します。
              * 
              * @param value
              *     allowed object is
@@ -573,9 +570,9 @@ public class CommandResultDTO {
 
 
     /**
-     * <p>Java class for anonymous complex type.
+     * <p>anonymous complex typeのJavaクラス。
      * 
-     * <p>The following schema fragment specifies the expected content contained within this class.
+     * <p>次のスキーマ・フラグメントは、このクラス内に含まれる予期されるコンテンツを指定します。
      * 
      * <pre>
      * &lt;complexType>
@@ -641,9 +638,9 @@ public class CommandResultDTO {
 
 
         /**
-         * <p>Java class for anonymous complex type.
+         * <p>anonymous complex typeのJavaクラス。
          * 
-         * <p>The following schema fragment specifies the expected content contained within this class.
+         * <p>次のスキーマ・フラグメントは、このクラス内に含まれる予期されるコンテンツを指定します。
          * 
          * <pre>
          * &lt;complexType>
@@ -671,7 +668,7 @@ public class CommandResultDTO {
             protected Double value;
 
             /**
-             * Gets the value of the key property.
+             * keyプロパティの値を取得します。
              * 
              * @return
              *     possible object is
@@ -683,7 +680,7 @@ public class CommandResultDTO {
             }
 
             /**
-             * Sets the value of the key property.
+             * keyプロパティの値を設定します。
              * 
              * @param value
              *     allowed object is
@@ -695,7 +692,7 @@ public class CommandResultDTO {
             }
 
             /**
-             * Gets the value of the value property.
+             * valueプロパティの値を取得します。
              * 
              * @return
              *     possible object is
@@ -707,7 +704,7 @@ public class CommandResultDTO {
             }
 
             /**
-             * Sets the value of the value property.
+             * valueプロパティの値を設定します。
              * 
              * @param value
              *     allowed object is
